@@ -501,9 +501,21 @@ class GutenbergDublinCore (DublinCore):
 
     def __init__ (self):
         DublinCore.__init__ (self)
-        self.project_gutenberg_id = None
         self.project_gutenberg_title = None
         self.is_format_of = None
+        self._project_gutenberg_id = None
+
+
+    @property
+    def project_gutenberg_id(self):
+        return self._project_gutenberg_id
+
+    @project_gutenberg_id.setter
+    def project_gutenberg_id(self, ebook):
+        self._project_gutenberg_id = int (ebook)
+        self.is_format_of = str (NS.ebook) + str (ebook)
+        self.canonical_url = re.sub(r'^http:', 'https:', self.is_format_of) + '/'
+
 
 
     def feed_to_writer(self, writer):
@@ -576,7 +588,7 @@ class GutenbergDublinCore (DublinCore):
                             self.project_gutenberg_id = int(contents)
                             self.is_format_of = str(NS.ebook) + str(self.project_gutenberg_id)
                         except ValueError:
-                            error('Invalid ebook no. in RST meta: %s' % contents)
+                            error('Invalid ebook no. in RST meta: %s', contents)
                             return False
                     elif name == 'title':
                         self.project_gutenberg_title = contents
@@ -585,7 +597,7 @@ class GutenbergDublinCore (DublinCore):
                             self.release_date = datetime.datetime.strptime(
                                 contents, '%Y-%m-%d').date()
                         except ValueError:
-                            error('Invalid date in RST meta: %s' % contents)
+                            error('Invalid date in RST meta: %s', contents)
                     elif name == 'rights':
                         if contents.lower() == 'copyrighted':
                             self.rights = 'Copyrighted.'
@@ -599,7 +611,7 @@ class GutenbergDublinCore (DublinCore):
                         try:
                             self.add_lang_id(contents)
                         except KeyError:
-                            error('Invalid language id RST meta: %s' % contents)
+                            error('Invalid language id RST meta: %s', contents)
                     elif name == 'created':
                         pass # published date
 
@@ -673,7 +685,7 @@ class GutenbergDublinCore (DublinCore):
                         pass
 
                 if not self.release_date:
-                    error ("Cannot understand date: %s" % date)
+                    error ("Cannot understand date: %s", date)
 
 
         def handle_ebook_no (self, text):
@@ -682,8 +694,6 @@ class GutenbergDublinCore (DublinCore):
             m = re.search (r'#(\d+)\]', text)
             if m:
                 self.project_gutenberg_id = int (m.group (1))
-                self.is_format_of = str (NS.ebook) + str (self.project_gutenberg_id)
-                self.canonical_url = re.sub(r'^http:', 'https:', self.is_format_of) + '/'
 
 
         def handle_languages (self, dummy_prefix, text):
